# Generated by roxygen2: do not edit by hand

export(roll_max)
export(roll_maxl)
export(roll_maxr)
export(roll_mean)
export(roll_meanl)
export(roll_meanr)
export(roll_median)
export(roll_medianl)
export(roll_medianr)
export(roll_min)
export(roll_minl)
export(roll_minr)
export(roll_prod)
export(roll_prodl)
export(roll_prodr)
export(roll_sd)
export(roll_sdl)
export(roll_sdr)
export(roll_sum)
export(roll_suml)
export(roll_sumr)
export(roll_var)
export(roll_varl)
export(roll_varr)
importFrom(Rcpp,evalCpp)
useDynLib(RcppRoll, .registration = TRUE)
