# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

na_locf <- function(x) {
    .Call(`_RcppRoll_na_locf`, x)
}

roll_mean_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_mean_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_median_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_median_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_min_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_min_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_max_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_max_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_prod_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_prod_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_sum_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_sum_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_sd_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_sd_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

roll_var_impl <- function(x, n, weights, by, fill_, partial, align, normalize, na_rm) {
    .Call(`_RcppRoll_roll_var_impl`, x, n, weights, by, fill_, partial, align, normalize, na_rm)
}

