% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/RcppRoll-package.R
\docType{package}
\name{RcppRoll}
\alias{RcppRoll}
\alias{RcppRoll-package}
\title{RcppRoll}
\description{
This package implements a number of 'roll'-ing functions for \R
vectors and matrices.
}
\details{
Currently, the exported functions are:
 \itemize{
 \item{\code{\link{roll_max}}}
 \item{\code{\link{roll_mean}}}
 \item{\code{\link{roll_median}}}
 \item{\code{\link{roll_min}}}
 \item{\code{\link{roll_prod}}}
 \item{\code{\link{roll_sd}}}
 \item{\code{\link{roll_sum}}}
 \item{\code{\link{roll_var}}}
 }
}
